@@ -1,7 +1,7 @@
 # vim:fileencoding=utf-8
-# Copyright (c) 2007 gocept gmbh & co. kg
+# Copyright (c) 2007-2009 gocept gmbh & co. kg
 # See also LICENSE.txt
-# $Id: content.py 5658 2008-04-08 12:46:08Z mac $
+# $Id: content.py 29374 2009-03-04 09:31:23Z thomas $
 """Interaction between the reference machinery and content objects."""
 
 import transaction
@@ -10,7 +10,7 @@ import zope.interface
 import zope.component
 import zope.traversing.interfaces
 import zope.traversing.api
-import zope.app.container.interfaces
+import zope.container.interfaces
 
 import gocept.reference.interfaces
 import gocept.reference.reference
@@ -34,10 +34,11 @@ class ReferenceSource(object):
     def verify_integrity(self):
         for name, ref in find_references(
             self.context):
-            target_key = ref.storage(self.context).get(name)
+            target_key = gocept.reference.reference.get_storage(
+                self.context).get(name)
             if target_key:
                 try:
-                    ref.lookup(target_key)
+                    gocept.reference.reference.lookup(target_key)
                 except gocept.reference.interfaces.LookupError:
                     return False
         return True
@@ -73,7 +74,7 @@ class ReferenceTarget(object):
 
 
 @zope.component.adapter(zope.interface.Interface,
-                        zope.app.container.interfaces.IObjectMovedEvent)
+                        zope.container.interfaces.IObjectMovedEvent)
 def ensure_referential_integrity(obj, event):
     if event.oldParent is None:
         # The object was not in the hierarchy before so it didn't have a path
@@ -108,14 +109,14 @@ def ensure_referential_integrity(obj, event):
 
 
 @zope.component.adapter(zope.interface.Interface,
-                        zope.app.container.interfaces.IObjectAddedEvent)
+                        zope.container.interfaces.IObjectAddedEvent)
 def ensure_registration(obj, event):
     for name, ref in find_references(obj):
         ref._register(obj)
 
 
 @zope.component.adapter(zope.interface.Interface,
-                        zope.app.container.interfaces.IObjectRemovedEvent)
+                        zope.container.interfaces.IObjectRemovedEvent)
 def ensure_unregistration(obj, event):
     for name, ref in find_references(obj):
         ref._unregister(obj)
