@@ -1,20 +1,19 @@
 # vim:fileencoding=utf-8
-# Copyright (c) 2007 gocept gmbh & co. kg
+# Copyright (c) 2007-2009 gocept gmbh & co. kg
 # See also LICENSE.txt
-# $Id$
 """Reference manager implementation."""
 
 import persistent
 import BTrees.OIBTree
 
-import zope.interface 
-import zope.app.container.contained
+import zope.interface
+import zope.container.contained
 
 import gocept.reference.interfaces
 
 
 class ReferenceManager(persistent.Persistent,
-                       zope.app.container.contained.Contained):
+                       zope.container.contained.Contained):
 
     zope.interface.implements(gocept.reference.interfaces.IReferenceManager)
 
